@@ -159,12 +159,13 @@ MARK_VISIBLE (gpgrt_calloc)
 MARK_VISIBLE (gpgrt_strdup)
 MARK_VISIBLE (gpgrt_strconcat)
 MARK_VISIBLE (gpgrt_free)
+MARK_VISIBLE (gpgrt_wipememory)
 MARK_VISIBLE (gpgrt_getenv)
 MARK_VISIBLE (gpgrt_setenv)
 MARK_VISIBLE (gpgrt_mkdir)
 MARK_VISIBLE (gpgrt_chdir)
 MARK_VISIBLE (gpgrt_getcwd)
-MARK_VISIBLE (gpgrt_access);
+MARK_VISIBLE (gpgrt_access)
 
 MARK_VISIBLE (gpgrt_b64dec_start)
 MARK_VISIBLE (gpgrt_b64dec_proc)
@@ -183,9 +184,11 @@ MARK_VISIBLE (gpgrt_log_get_prefix)
 MARK_VISIBLE (gpgrt_log_test_fd)
 MARK_VISIBLE (gpgrt_log_get_fd)
 MARK_VISIBLE (gpgrt_log_get_stream)
+MARK_VISIBLE (gpgrt_add_post_log_func)
 MARK_VISIBLE (gpgrt_log)
 MARK_VISIBLE (gpgrt_logv)
 MARK_VISIBLE (gpgrt_logv_prefix)
+MARK_VISIBLE (gpgrt_logv_domain)
 MARK_VISIBLE (gpgrt_log_string)
 MARK_VISIBLE (gpgrt_log_bug)
 MARK_VISIBLE (gpgrt_log_fatal)
@@ -201,29 +204,70 @@ MARK_VISIBLE (_gpgrt_log_assert)
 
 #if 0
 MARK_VISIBLE (gpgrt_make_pipe)
-MARK_VISIBLE (gpgrt_spawn_process)
-MARK_VISIBLE (gpgrt_spawn_process_fd)
-MARK_VISIBLE (gpgrt_spawn_process_detached)
-MARK_VISIBLE (gpgrt_wait_process)
-MARK_VISIBLE (gpgrt_wait_processes)
-MARK_VISIBLE (gpgrt_kill_process)
-MARK_VISIBLE (gpgrt_release_process)
+MARK_VISIBLE (gpgrt_close_all_fds)
 #endif
 
+MARK_VISIBLE (gpgrt_process_spawn)
+MARK_VISIBLE (gpgrt_process_terminate)
+MARK_VISIBLE (gpgrt_process_get_fds)
+MARK_VISIBLE (gpgrt_process_get_streams)
+MARK_VISIBLE (gpgrt_process_ctl)
+MARK_VISIBLE (gpgrt_process_wait)
+MARK_VISIBLE (gpgrt_process_release)
+
 MARK_VISIBLE (gpgrt_argparse)
 MARK_VISIBLE (gpgrt_argparser)
 MARK_VISIBLE (gpgrt_usage)
 MARK_VISIBLE (gpgrt_strusage)
 MARK_VISIBLE (gpgrt_set_strusage)
-MARK_VISIBLE (gpgrt_set_fixed_string_mapper);
-MARK_VISIBLE (gpgrt_set_usage_outfnc);
-MARK_VISIBLE (gpgrt_set_confdir);
+MARK_VISIBLE (gpgrt_set_fixed_string_mapper)
+MARK_VISIBLE (gpgrt_set_usage_outfnc)
+MARK_VISIBLE (gpgrt_set_confdir)
 
-MARK_VISIBLE (gpgrt_cmp_version);
+MARK_VISIBLE (gpgrt_cmp_version)
 
-MARK_VISIBLE (gpgrt_fnameconcat);
-MARK_VISIBLE (gpgrt_absfnameconcat);
+MARK_VISIBLE (gpgrt_fnameconcat)
+MARK_VISIBLE (gpgrt_absfnameconcat)
 
+MARK_VISIBLE (gpgrt_strlist_free)
+MARK_VISIBLE (gpgrt_strlist_add)
+MARK_VISIBLE (gpgrt_strlist_tokenize)
+MARK_VISIBLE (gpgrt_strlist_copy)
+MARK_VISIBLE (gpgrt_strlist_rev)
+MARK_VISIBLE (gpgrt_strlist_prev)
+MARK_VISIBLE (gpgrt_strlist_last)
+MARK_VISIBLE (gpgrt_strlist_pop)
+MARK_VISIBLE (gpgrt_strlist_find)
+
+MARK_VISIBLE (gpgrt_nvc_new)
+MARK_VISIBLE (gpgrt_nvc_release)
+MARK_VISIBLE (gpgrt_nvc_get_flag)
+MARK_VISIBLE (gpgrt_nvc_add)
+MARK_VISIBLE (gpgrt_nvc_set)
+MARK_VISIBLE (gpgrt_nve_set)
+MARK_VISIBLE (gpgrt_nvc_delete)
+MARK_VISIBLE (gpgrt_nvc_lookup)
+MARK_VISIBLE (gpgrt_nvc_parse)
+MARK_VISIBLE (gpgrt_nvc_write)
+MARK_VISIBLE (gpgrt_nve_next)
+MARK_VISIBLE (gpgrt_nve_name)
+MARK_VISIBLE (gpgrt_nve_value)
+MARK_VISIBLE (gpgrt_nvc_get_string)
+MARK_VISIBLE (gpgrt_nvc_get_bool)
+
+MARK_VISIBLE (gpgrt_spawn_actions_new)
+MARK_VISIBLE (gpgrt_spawn_actions_release)
+MARK_VISIBLE (gpgrt_spawn_actions_set_env_rev)
+#ifdef HAVE_W32_SYSTEM
+MARK_VISIBLE (gpgrt_spawn_actions_set_envvars)
+MARK_VISIBLE (gpgrt_spawn_actions_set_redirect)
+MARK_VISIBLE (gpgrt_spawn_actions_set_inherit_handles)
+#else
+MARK_VISIBLE (gpgrt_spawn_actions_set_environ)
+MARK_VISIBLE (gpgrt_spawn_actions_set_redirect)
+MARK_VISIBLE (gpgrt_spawn_actions_set_inherit_fds)
+MARK_VISIBLE (gpgrt_spawn_actions_set_atfork)
+#endif
 
 
 #undef MARK_VISIBLE
@@ -344,6 +388,7 @@ MARK_VISIBLE (gpgrt_absfnameconcat);
 #define gpgrt_strdup                _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_strconcat             _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_free                  _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_wipememory            _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_getenv                _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_setenv                _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_mkdir                 _gpgrt_USE_UNDERSCORED_FUNCTION
@@ -372,9 +417,11 @@ MARK_VISIBLE (gpgrt_absfnameconcat);
 #define gpgrt_log_test_fd           _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_log_get_fd            _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_log_get_stream        _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_add_post_log_func     _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_log                   _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_logv                  _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_logv_prefix           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_logv_domain           _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_log_string            _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_log_bug               _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_log_fatal             _gpgrt_USE_UNDERSCORED_FUNCTION
@@ -388,14 +435,32 @@ MARK_VISIBLE (gpgrt_absfnameconcat);
 #define gpgrt_log_flush             _gpgrt_USE_UNDERSCORED_FUNCTION
 #define _gpgrt_log_assert           _gpgrt_USE_UNDERSCORED_FUNCTION
 
+#if 0
 #define gpgrt_make_pipe              _gpgrt_USE_UNDERSCORED_FUNCTION
-#define gpgrt_spawn_process          _gpgrt_USE_UNDERSCORED_FUNCTION
-#define gpgrt_spawn_process_fd       _gpgrt_USE_UNDERSCORED_FUNCTION
-#define gpgrt_spawn_process_detached _gpgrt_USE_UNDERSCORED_FUNCTION
-#define gpgrt_wait_process           _gpgrt_USE_UNDERSCORED_FUNCTION
-#define gpgrt_wait_processes         _gpgrt_USE_UNDERSCORED_FUNCTION
-#define gpgrt_kill_process           _gpgrt_USE_UNDERSCORED_FUNCTION
-#define gpgrt_release_process        _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_close_all_fds          _gpgrt_USE_UNDERSCORED_FUNCTION
+#endif
+
+#define gpgrt_process_spawn          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_process_terminate      _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_process_get_fds        _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_process_get_streams    _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_process_ctl            _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_process_wait           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_process_release        _gpgrt_USE_UNDERSCORED_FUNCTION
+
+#define gpgrt_spawn_actions_new                 _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_spawn_actions_release             _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_spawn_actions_set_env_rev         _gpgrt_USE_UNDERSCORED_FUNCTION
+#ifdef HAVE_W32_SYSTEM
+#define gpgrt_spawn_actions_set_envvars         _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_spawn_actions_set_redirect        _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_spawn_actions_set_inherit_handles _gpgrt_USE_UNDERSCORED_FUNCTION
+#else
+#define gpgrt_spawn_actions_set_environ         _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_spawn_actions_set_redirect        _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_spawn_actions_set_inherit_fds     _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_spawn_actions_set_atfork          _gpgrt_USE_UNDERSCORED_FUNCTION
+#endif
 
 #define gpgrt_argparse                _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_argparser               _gpgrt_USE_UNDERSCORED_FUNCTION
@@ -410,8 +475,39 @@ MARK_VISIBLE (gpgrt_absfnameconcat);
 #define gpgrt_fnameconcat           _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_absfnameconcat        _gpgrt_USE_UNDERSCORED_FUNCTION
 
+#define gpgrt_strlist_free          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_add           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_tokenize      _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_copy          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_rev           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_prev          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_last          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_pop           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_find          _gpgrt_USE_UNDERSCORED_FUNCTION
+
+#define gpgrt_nvc_new               _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_release           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_get_flag          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_add               _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_set               _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nve_set               _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_delete            _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_lookup            _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_parse             _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_write             _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nve_next              _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nve_name              _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nve_value             _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_get_string        _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_get_bool          _gpgrt_USE_UNDERSCORED_FUNCTION
+
 /* Windows specific functions.  */
+#define gpgrt_free_wchar            _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_utf8_to_wchar         _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_wchar_to_utf8         _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_fname_to_wchar        _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_w32_reg_query_string  _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_w32_reg_get_string    _gpgrt_USE_UNDERSCORED_FUNCTION
 
 
 #endif /*!_GPGRT_INCL_BY_VISIBILITY_C*/
